===========
pysimpleapp
===========


.. image:: https://img.shields.io/pypi/v/pysimpleapp.svg
        :target: https://pypi.python.org/pypi/pysimpleapp

.. image:: https://img.shields.io/travis/MagpieEmbedded/pysimpleapp.svg
        :target: https://travis-ci.org/MagpieEmbedded/pysimpleapp

.. image:: https://readthedocs.org/projects/pysimpleapp/badge/?version=latest
        :target: https://pysimpleapp.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Simple framework for applications in python

Aims
----

This package is intended to provide the basic components for a  graphical application in Python.
It grew out of a frustration with existing tutorials on writing GUI applications in Python.

It is intended to be GUI framework agnostic, although some common frameworks have been included for demonstration and ease of use.

There should also be a relatively thorough set of tutorials alongside the main code.
This will teach how to use the software.
Read the documentation to find out why the software is this way.


* Free software: MIT license
* Documentation: https://pysimpleapp.readthedocs.io.


Features
--------

* TODO
* Attempt to implement best practices
* Documentation and tutorials

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
